@@ -821,7 +821,7 @@ def Clift(Re):
     If 0.01 < Re < 20:
 
     .. math::
-        C_D = \frac{24}{Re}(1 + 0.1315Re^{0.82 - 0.05\log Re})
+        C_D = \frac{24}{Re}(1 + 0.1315Re^{0.82 - 0.05\log_{10} Re})
 
     If 20 < Re < 260:
 
@@ -831,32 +831,32 @@ def Clift(Re):
     If 260 < Re < 1500:
 
     .. math::
-        C_D = 10^{[1.6435 - 1.1242\log Re + 0.1558[\log Re]^2}
+        C_D = 10^{[1.6435 - 1.1242\log_{10} Re + 0.1558[\log_{10} Re]^2}
 
     If 1500 < Re < 12000:
 
     .. math::
-        C_D = 10^{[-2.4571 + 2.5558\log Re - 0.9295[\log Re]^2 + 0.1049[\log Re]^3}
+        C_D = 10^{[-2.4571 + 2.5558\log_{10} Re - 0.9295[\log_{10} Re]^2 + 0.1049[\log_{10} Re]^3}
 
     If 12000 < Re < 44000:
 
     .. math::
-        C_D = 10^{[-1.9181 + 0.6370\log Re - 0.0636[\log Re]^2}
+        C_D = 10^{[-1.9181 + 0.6370\log_{10} Re - 0.0636[\log_{10} Re]^2}
 
     If 44000 < Re < 338000:
 
     .. math::
-        C_D = 10^{[-4.3390 + 1.5809\log Re - 0.1546[\log Re]^2}
+        C_D = 10^{[-4.3390 + 1.5809\log_{10} Re - 0.1546[\log_{10} Re]^2}
 
     If 338000 < Re < 400000:
 
     .. math::
-        C_D = 9.78 - 5.3\log Re
+        C_D = 9.78 - 5.3\log_{10} Re
 
     If 400000 < Re < 1000000:
 
     .. math::
-        C_D = 0.19\log Re - 0.49
+        C_D = 0.19\log_{10} Re - 0.49
 
     Parameters
     ----------
