@@ -38,6 +38,9 @@ import linecache
 import numba.types
 from math import pi
 import fluids.optional.spa
+import ctypes
+from numba.extending import get_cython_function_address
+from numba.extending import overload
 
 
 caching = True
@@ -48,6 +51,56 @@ __all__ = []
 __funcs = {}
 no_conv_data_names = set(['__builtins__', 'fmethods'])
 
+try:
+    import scipy.special as sc
+    name_to_numba_signatures = {
+        'ellipe': [(float64,)],
+        'iv': [(float64, float64,)],
+        'gamma': [(float64,)],
+        'gammainc': [(float64, float64,)],
+        'gammaincc': [(float64, float64,)],
+        'i0': [(float64,)],
+        'i1': [(float64,)],
+        'k0': [(float64,)],
+        'k1': [(float64,)],
+        'hyp2f1': [(float64, float64, float64, float64,)],
+        'ellipkinc': [(float64, float64,)],
+        'ellipeinc': [(float64, float64,)],
+        'erf': [(float64,)],
+    }
+
+    name_and_types_to_pointer = {
+        ('ellipe', float64): ctypes.CFUNCTYPE(ctypes.c_double, ctypes.c_double)(get_cython_function_address('scipy.special.cython_special', 'ellipe')),
+        ('iv', float64, float64): ctypes.CFUNCTYPE(ctypes.c_double, ctypes.c_double, ctypes.c_double)(get_cython_function_address('scipy.special.cython_special', '__pyx_fuse_1iv')),
+        ('gamma', float64): ctypes.CFUNCTYPE(ctypes.c_double, ctypes.c_double)(get_cython_function_address('scipy.special.cython_special', '__pyx_fuse_1gamma')),
+        ('gammainc', float64, float64): ctypes.CFUNCTYPE(ctypes.c_double, ctypes.c_double, ctypes.c_double)(get_cython_function_address('scipy.special.cython_special', 'gammainc')),
+        ('gammaincc', float64, float64): ctypes.CFUNCTYPE(ctypes.c_double, ctypes.c_double, ctypes.c_double)(get_cython_function_address('scipy.special.cython_special', 'gammaincc')),
+        ('i0', float64): ctypes.CFUNCTYPE(ctypes.c_double, ctypes.c_double)(get_cython_function_address('scipy.special.cython_special', 'i0')),
+        ('i1', float64): ctypes.CFUNCTYPE(ctypes.c_double, ctypes.c_double)(get_cython_function_address('scipy.special.cython_special', 'i1')),
+        ('k0', float64): ctypes.CFUNCTYPE(ctypes.c_double, ctypes.c_double)(get_cython_function_address('scipy.special.cython_special', 'k0')),
+        ('k1', float64): ctypes.CFUNCTYPE(ctypes.c_double, ctypes.c_double)(get_cython_function_address('scipy.special.cython_special', 'k1')),
+        ('hyp2f1', float64, float64, float64, float64): ctypes.CFUNCTYPE(ctypes.c_double, ctypes.c_double, ctypes.c_double, ctypes.c_double, ctypes.c_double)(get_cython_function_address('scipy.special.cython_special', '__pyx_fuse_1hyp2f1')),
+        ('ellipkinc', float64, float64): ctypes.CFUNCTYPE(ctypes.c_double, ctypes.c_double, ctypes.c_double)(get_cython_function_address('scipy.special.cython_special', 'ellipkinc')),
+        ('ellipeinc', float64, float64): ctypes.CFUNCTYPE(ctypes.c_double, ctypes.c_double, ctypes.c_double)(get_cython_function_address('scipy.special.cython_special', 'ellipeinc')),
+        ('erf', float64): ctypes.CFUNCTYPE(ctypes.c_double, ctypes.c_double)(get_cython_function_address('scipy.special.cython_special', '__pyx_fuse_1erf')),
+    }
+
+    def select_kernel(name, signature):
+        f2 = name_and_types_to_pointer[(name, *signature)]
+        second_lambda = lambda *args: lambda *args: f2(*args)
+        return second_lambda
+
+    def add_scipy_special_overloads():
+        for name, sigs in name_to_numba_signatures.items():
+            sig = sigs[0] # Sig is a tuple of arguments
+            func = getattr(sc, name)
+            overload(func)(select_kernel(name, sigs[0]))
+
+    add_scipy_special_overloads()
+
+except:
+    pass
+
 
 def numba_exec_cacheable(source, lcs=None, gbls=None, cache_name='cache-safe'):
     filepath = "<ipython-%s>" % cache_name
@@ -255,7 +308,7 @@ def transform_lists_to_arrays(module, to_change, __funcs, vec=False, cache_black
             source = re.sub(list_mult_expr, numpy_not_list_expr, source)
             parallel = 'prange' in source
             source = re.sub(match_prange, sub_prange, source)
-#        if 'Lindsay_Bromley' in source:
+#        if 'roughness_Farshad' in source:
 #            print(source)
 #            print(parallel, 'hi', extra_args)
         numba_exec_cacheable(source, fake_mod.__dict__, fake_mod.__dict__)
@@ -435,12 +488,13 @@ def transform_module(normal, __funcs, replaced, vec=False, blacklist=frozenset([
     else:
         conv_fun = numba.njit
         extra_args = extra_args_std
-    mod_name = normal.__name__
     # Run module-by-module. Expensive, as we need to create module copies
     try:
         all_submodules = normal.all_submodules()
     except:
         all_submodules = normal.submodules
+    numtypes = {float, int, complex}
+    settypes = {set, frozenset}
     for mod in all_submodules:
         #print(all_submodules, mod)
         SUBMOD_COPY = importlib.util.find_spec(mod.__name__)
@@ -460,95 +514,83 @@ def transform_module(normal, __funcs, replaced, vec=False, blacklist=frozenset([
 
         SUBMOD.__dict__.update(replaced)
         new_mods.append(SUBMOD)
-        __funcs[mod.__name__.split('.')[-1]] = SUBMOD # fluids.numba.optional.spa
-        __funcs['.'.join(mod.__name__.split('.')[:-1])] = SUBMOD # set fluids.optional.spa fluids.numba.spa
-        __funcs['.'.join(mod.__name__.split('.')[-2:])] = SUBMOD # set 'optional.spa' in the dict too
-        try:
-            names = list(SUBMOD.__all__)
-        except:
-            names = []
+        mod_split_names = mod.__name__.split('.')
+        __funcs[mod_split_names[-1]] = SUBMOD # fluids.numba.optional.spa
+        __funcs['.'.join(mod_split_names[:-1])] = SUBMOD # set fluids.optional.spa fluids.numba.spa
+        __funcs['.'.join(mod_split_names[-2:])] = SUBMOD # set 'optional.spa' in the dict too
 
-        allow_fail_names = set([])
+        try:
+            names = set(SUBMOD.__all__)
+        except:
+            names = set()
         for mod_obj_name in dir(SUBMOD):
             obj = getattr(SUBMOD, mod_obj_name)
-            if isinstance(obj, types.FunctionType):
-                if mod_obj_name in ('__getattr__',):
-                    # Names which cannot be converted
-                    continue
-                if mod_obj_name.startswith('_load'):
-                    continue
-
-                if mod_obj_name not in names:
-                    # Check if the function is local to the module
-                    if obj.__module__ == SUBMOD.__name__:
-                        names.append(mod_obj_name)
-                        allow_fail_names.add(mod_obj_name)
+            if (isinstance(obj, types.FunctionType)
+                and mod_obj_name != '__getattr__'
+                and not mod_obj_name.startswith('_load')
+                and obj.__module__ == SUBMOD.__name__):
+                names.add(mod_obj_name)
 
         # try:
         #     names += SUBMOD.__numba_additional_funcs__
         # except:
         #     pass
 
-        new_objs = []
+        numba_funcs = []
+        funcs = []
         for name in names:
             obj = getattr(SUBMOD, name)
             if isinstance(obj, types.FunctionType):
-                nopython = name not in skip
                 if name not in total_skip and name not in blacklist:
-                    try:
-                        obj = conv_fun(cache=(caching and name not in cache_blacklist), **extra_args)(obj)
-                    except Exception as e:
-                        if name in mod_obj_name:
-                            continue
-                        else:
-                            raise e
-                SUBMOD.__dict__[name] = obj
-                new_objs.append(obj)
+                    SUBMOD.__dict__[name] = obj = conv_fun(cache=(caching and name not in cache_blacklist), **extra_args)(obj)
+                    numba_funcs.append(obj)
+                else:
+                    funcs.append(obj)
             __funcs[name] = obj
 
         module_constants_changed_type = {}
-        for arr_name in SUBMOD.__dict__.keys():
-            if arr_name not in no_conv_data_names:
-                obj = getattr(SUBMOD, arr_name)
-                obj_type = type(obj)
-                if obj_type is list and len(obj) and type(obj[0]) in (float, int, complex):
-                    module_constants_changed_type[arr_name] = np.array(obj)
-                elif (obj_type is list and len(obj) and all([
-                        (type(r) is list and len(r) and type(r[0]) in (float, int, complex)) for r in obj])):
+        for arr_name in SUBMOD.__dict__:
+            if arr_name in no_conv_data_names: continue
+            obj = getattr(SUBMOD, arr_name)
+            obj_type = type(obj)
+            if obj_type is list and obj:
+                # Assume all elements have the same general type
+                r = obj[0]
+                r_type = type(r)
+                if r_type in numtypes:
+                    arr = np.array(obj)
+                    if arr.dtype.char != 'O': module_constants_changed_type[arr_name] = arr
+                elif r_type is list and r and type(r[0]) in numtypes:
                     if len(set([len(r) for r in obj])) == 1:
                         # All same size - nice numpy array
-                        module_constants_changed_type[arr_name] = np.array(obj)
+                        arr = np.array(obj)
+                        if arr.dtype.char != 'O': module_constants_changed_type[arr_name] = arr
                     else:
                         # Tuple of different size numpy arrays
-                        module_constants_changed_type[arr_name] = tuple(np.array(v) for v in obj)
-                elif obj_type in (set, frozenset):
-                    module_constants_changed_type[arr_name] = tuple(obj)
-                elif obj_type is dict:
-                    continue
-                    try:
-                        print('starting', arr_name)
-                        infer_dictionary_types(obj)
-                        module_constants_changed_type[arr_name] = numba_dict(obj)
-                    except:
-                        print(arr_name, 'failed')
-                        pass
+                        module_constants_changed_type[arr_name] = tuple([np.array(v) for v in obj])
+            elif obj_type in settypes:
+                module_constants_changed_type[arr_name] = tuple(obj)
+            # elif obj_type is dict:
+            #     try:
+            #         print('starting', arr_name)
+            #         infer_dictionary_types(obj)
+            #         module_constants_changed_type[arr_name] = numba_dict(obj)
+            #     except:
+            #         print(arr_name, 'failed')
+            #         pass
 
         SUBMOD.__dict__.update(module_constants_changed_type)
         __funcs.update(module_constants_changed_type)
 
         if not vec:
-            for t in new_objs:
+            for t in numba_funcs:
                 #if normal.__name__ == 'chemicals':
                 #    if 'iapws' not in all_submodules[-1].__name__:
                 #        print(new_objs, t)
                 #        1/0
-                try:
-                    glob = t.py_func.__globals__
-                except:
-                    glob = t.__globals__
-                glob.update(SUBMOD.__dict__)
-                #glob.update(to_do)
-                glob.update(replaced)
+                t.py_func.__globals__.update(SUBMOD.__dict__)
+            for t in funcs:
+                t.__globals__.update(SUBMOD.__dict__)
 
     # Do our best to allow functions to be found
     if '__file__' in __funcs:
@@ -557,8 +599,6 @@ def transform_module(normal, __funcs, replaced, vec=False, blacklist=frozenset([
         del replaced['__file__']
     for mod in new_mods:
         mod.__dict__.update(__funcs)
-        mod.__dict__.update(replaced)
-
     return new_mods
 
 
@@ -575,7 +615,7 @@ def transform_complete(replaced, __funcs, __all__, normal, vec=False):
    'SA_partial_horiz_spherical_head', '_SA_partial_horiz_spherical_head_to_int',
    '_SA_partial_horiz_ellipsoidal_head_to_int', '_SA_partial_horiz_ellipsoidal_head_limits', 'SA_partial_horiz_ellipsoidal_head',
    '_SA_partial_horiz_guppy_head_to_int', 'SA_partial_horiz_guppy_head', 'SA_partial_horiz_torispherical_head',
-   'SA_from_h'])
+   'SA_from_h', 'V_tank'])
 #    cache_blacklist = set([])
     if vec:
         conv_fun = numba.vectorize
@@ -592,6 +632,7 @@ def transform_complete(replaced, __funcs, __all__, normal, vec=False):
                  'optional.spa.solar_position', 'optional.spa.longitude_obliquity_nutation',
                  'optional.spa.transit_sunrise_sunset',
                  'fittings.bend_rounded_Crane', 'geometry.tank_from_two_specs_err',
+                 'friction.roughness_Farshad',
                  ]
     transform_lists_to_arrays(normal_fluids, to_change, __funcs, vec=vec, cache_blacklist=cache_blacklist)
 
@@ -600,7 +641,7 @@ def transform_complete(replaced, __funcs, __all__, normal, vec=False):
     # calls to method functions
 
     to_change = {}
-    to_change['friction.roughness_Farshad'] = 'ID in _Farshad_roughness'
+#    to_change['friction.roughness_Farshad'] = 'ID in _Farshad_roughness'
 
     for s, bad_branch in to_change.items():
         mod, func = s.split('.')
@@ -621,7 +662,7 @@ def transform_complete(replaced, __funcs, __all__, normal, vec=False):
                            'plate_enlargement_factor', 'D_eq', 'D_hydraulic', 'width', 'length', 'thickness',
                            'd_port', 'plates', 'length_port', 'A_plate_surface', 'A_heat_transfer',
                            'A_channel_flow', 'channels', 'channels_per_fluid')]
-    PlateExchanger_spec.append(('chevron_angles', numba.types.UniTuple(numba.types.float64, 2)))
+    PlateExchanger_spec.append(('chevron_angles', numba.types.UniTuple(float64, 2)))
 
     HelicalCoil_spec = [(k, float64) for k in
                         ('Do', 'Dt', 'Di', 'Do_total', 'N', 'pitch', 'H', 'H_total',
