@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
-Copyright (C) 2017, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
+Copyright (C) 2017, 2018, 2019, 2020, 2021, Caleb Bell <Caleb.Andrew.Bell@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -28,6 +28,8 @@ __all__ = ['wraps_numpydoc', 'u']
 import types
 import re
 import inspect
+import sys
+from inspect import getsource, cleandoc
 import functools
 try:
     from collections.abc import Iterable
@@ -50,8 +52,43 @@ except ImportError: # pragma: no cover
 
 '''See fluids.units.rst for documentation for this module.
 '''
+
+try:
+    doc_stripped = sys.flags.optimize == 2
+except:
+    doc_stripped = False
 # is_critical_flow is broken
 
+def get_docstring(f):
+    '''Returns the docstring of a function, working in -OO mode also.
+    '''
+    try:
+        if f.__doc__ is not None:
+            return f.__doc__
+    except:
+        # micropython
+        return None
+    if not doc_stripped:
+        return None
+    src = cleandoc(inspect.getsource(f))
+    single_pos = src.find("'''")
+    double_pos = src.find('"""')
+    if single_pos == -1:
+        if double_pos == -1:
+            # Neither
+            return None
+        # double, not single
+        return cleandoc(src.split('"""')[1])
+    elif double_pos == -1 and single_pos != -1:
+        # single, not double
+        return cleandoc(src.split("'''")[1])
+    else:
+        # single and double
+        if single_pos < double_pos:
+            return cleandoc(src.split("'''")[1])
+        return cleandoc(src.split('"""')[1])
+
+
 def func_args(func):
     """Basic function which returns a tuple of arguments of a function or
     method."""
@@ -65,20 +102,23 @@ u.autoconvert_offset_to_baseunit = True
 
 expr = re.compile('Parameters *\n *-+\n +')
 expr2 = re.compile('Returns *\n *-+\n +')
-match_sections = re.compile('\n *[A-Za-z ]+ *\n +-+')
-match_section_names = re.compile('\n *[A-Za-z]+ *\n +-+')
+match_sections = re.compile('\n *[A-Za-z ]+ *\n *-+')
+match_section_names = re.compile('\n *[A-Za-z]+ *\n *-+')
 variable = re.compile('[a-zA-Z_0-9]* : ')
 match_units = re.compile(r'\[[a-zA-Z0-9().\/*^\- ]*\]')
 
 
+parse_numpydoc_variables_units_cache = {}
 def parse_numpydoc_variables_units(func):
-    try:
-        text = func.__doc__
-    except:
-        text = ''
+    text = get_docstring(func)
     if text is None:
         text = ''
-    return parse_numpydoc_variables_units_docstring(text)
+    h = hash(text)
+    if h in parse_numpydoc_variables_units_cache:
+        return parse_numpydoc_variables_units_cache[h]
+    res = parse_numpydoc_variables_units_docstring(text)
+    parse_numpydoc_variables_units_cache[h] = res
+    return res
 
 def parse_numpydoc_variables_units_docstring(text):
     section_names = [i.replace('-', '').strip() for i in match_sections.findall(text)]
@@ -135,8 +175,8 @@ def check_args_order(func):
         argspec = inspect.getargspec(func)
     parsed_data = parse_numpydoc_variables_units(func)
     # compare the parsed arguments with those actually defined
-    parsed_units = parsed_data['Parameters']['units']
-    parsed_parameters = parsed_data['Parameters']['vars']
+    parsed_units = copy(parsed_data['Parameters']['units'])
+    parsed_parameters = copy(parsed_data['Parameters']['vars'])
     if 'Other Parameters' in parsed_data:
         parsed_parameters += parsed_data['Other Parameters']['vars']
         parsed_units += parsed_data['Other Parameters']['units']
@@ -226,8 +266,8 @@ def wraps_numpydoc(ureg, strict=True):
         updated = (attr for attr in functools.WRAPPER_UPDATES if hasattr(func, attr))
         parsed_info = parse_numpydoc_variables_units(func)
 
-        in_vars = parsed_info['Parameters']['vars']
-        in_units = parsed_info['Parameters']['units']
+        in_vars = copy(parsed_info['Parameters']['vars'])
+        in_units = copy(parsed_info['Parameters']['units'])
         if 'Other Parameters' in parsed_info:
             in_vars += parsed_info['Other Parameters']['vars']
             in_units += parsed_info['Other Parameters']['units']
@@ -431,7 +471,7 @@ def wrap_numpydoc_obj(obj_to_wrap):
                 #name = attr.fget.__name__
             else:
                 name = attr.__name__
-            if hasattr(attr, '__doc__'):
+            if hasattr(attr, '__doc__') and attr.__doc__ is not None:
                 if type(attr) is property:
                     try:
                         docstring = attr.__doc__
@@ -439,9 +479,9 @@ def wrap_numpydoc_obj(obj_to_wrap):
                             docstring = attr.fget.__doc__
                         # Is it a full style string?
                         if 'Returns' in docstring and '-------' in docstring:
-                                found_unit = u(parse_numpydoc_variables_units_docstring(docstring)['Returns']['units'][0])
+                                found_unit = parse_expression_cached(parse_numpydoc_variables_units_docstring(docstring)['Returns']['units'][0], u)
                         else:
-                            found_unit = u(match_parse_units(docstring, i=0))
+                            found_unit = parse_expression_cached(match_parse_units(docstring, i=0), u)
                     except Exception as e:
                         if name[0] == '_':
                             found_unit = u.dimensionless
@@ -463,12 +503,12 @@ def wrap_numpydoc_obj(obj_to_wrap):
         callable_methods['__init__'] = clean_parsed_info(parsed)
 
         if 'Attributes' in parsed:
-            property_unit_map.update({var:u(unit) for var, unit in zip(parsed['Attributes']['vars'], parsed['Attributes']['units'])} )
+            property_unit_map.update({var:parse_expression_cached(unit, u) for var, unit in zip(parsed['Attributes']['vars'], parsed['Attributes']['units'])} )
         if 'Parameters' in parsed:
-            property_unit_map.update({var:u(unit) for var, unit in zip(parsed['Parameters']['vars'], parsed['Parameters']['units'])} )
+            property_unit_map.update({var:parse_expression_cached(unit, u) for var, unit in zip(parsed['Parameters']['vars'], parsed['Parameters']['units'])} )
 
     name = obj_to_wrap.__name__
-    classkwargs = {'wrapped': obj_to_wrap, #'__doc__': obj_to_wrap.__doc__,
+    classkwargs = {'wrapped': obj_to_wrap,
             'property_units': property_unit_map, 'method_units': callable_methods,
                    'static_methods': static_methods, 'class_methods': class_methods}
 
@@ -508,6 +548,8 @@ for name in dir(fluids):
         continue
     if 'ParticleSizeDistribution' in name:
         continue
+    if name == '__getattr__' or name == '__test__':
+        continue
     obj = getattr(fluids, name)
     if isinstance(obj, types.FunctionType):
         obj = wraps_numpydoc(u)(obj)
@@ -537,8 +579,6 @@ def A_multiple_hole_cylinder(Do, L, holes):
     A = fluids.geometry.A_multiple_hole_cylinder(Do, L, holes)
     return A*u.m**2
 
-#A_multiple_hole_cylinder.__doc__ = fluids.geometry.A_multiple_hole_cylinder.__doc__
-
 def V_multiple_hole_cylinder(Do, L, holes):
     Do = Do.to(u.m).magnitude
     L = L.to(u.m).magnitude
@@ -546,8 +586,6 @@ def V_multiple_hole_cylinder(Do, L, holes):
     A = fluids.geometry.V_multiple_hole_cylinder(Do, L, holes)
     return A*u.m**3
 
-#V_multiple_hole_cylinder.__doc__ = fluids.geometry.V_multiple_hole_cylinder.__doc__
-
 variable_output_unit_funcs = {
     # True: arg should be present; False: arg should be None
     'nu_mu_converter': ({(True, False, True): [u.Pa*u.s],
@@ -605,7 +643,4 @@ def variable_output_wrapper(func, wrapped_basic_func, output_signatures, input_l
 
 for name, val in variable_output_unit_funcs.items():
     globals()[name] = variable_output_wrapper(getattr(fluids, name),
-            __pint_wrapped_functions[name], val[0], val[1])
-
-
-# NOTE: class support can't do static methods unless a class is already instantiated
\ No newline at end of file
+            __pint_wrapped_functions[name], val[0], val[1])
\ No newline at end of file
